@@ -632,6 +632,9 @@ pub(crate) fn resolve_identifier<I: Interrupt>(
 		"unitless" => Value::Num(Box::new(Number::from(1))),
 		"arg" => Value::BuiltInFunction(BuiltInFunction::Arg),
 		"abs" => Value::BuiltInFunction(BuiltInFunction::Abs),
+		"floor" => Value::BuiltInFunction(BuiltInFunction::Floor),
+		"ceil" => Value::BuiltInFunction(BuiltInFunction::Ceil),
+		"round" => Value::BuiltInFunction(BuiltInFunction::Round),
 		"sin" => Value::BuiltInFunction(BuiltInFunction::Sin),
 		"cos" => Value::BuiltInFunction(BuiltInFunction::Cos),
 		"tan" => Value::BuiltInFunction(BuiltInFunction::Tan),
