@@ -2675,6 +2675,33 @@ fn factorial_of_three_kg() {
 	expect_error("(3 kg)!", None);
 }
 
+#[test]
+fn test_floor() {
+	test_eval("floor(3)", "3");
+	test_eval("floor(3.9)", "3");
+	test_eval("floor(-3)", "-3");
+	test_eval("floor(-3.1)", "-4");
+}
+
+#[test]
+fn test_ceil() {
+	test_eval("ceil(3)", "3");
+	test_eval("ceil(3.3)", "4");
+	test_eval("ceil(-3)", "-3");
+	test_eval("ceil(-3.3)", "-3");
+}
+
+#[test]
+fn test_round() {
+	test_eval("round(3)", "3");
+
+	test_eval("round(3.3)", "3");
+	test_eval("round(3.7)", "4");
+
+	test_eval("round(-3.3)", "-3");
+	test_eval("round(-3.7)", "-4");
+}
+
 #[test]
 fn recurring_digits_1() {
 	test_eval_simple("9/11 to float", "0.(81)");
@@ -5370,6 +5397,11 @@ fn gbp_symbol() {
 	test_eval("£5 + £3", "£8");
 }
 
+#[test]
+fn jpy_symbol() {
+	test_eval("¥5 + ¥3", "¥8");
+}
+
 #[test]
 fn two_statements() {
 	test_eval("2; 4", "4");
@@ -5832,3 +5864,9 @@ fn alias_sqrt() {
 		"approx. 3527.6684147527 s",
 	);
 }
+
+#[test]
+fn test_superscript() {
+	test_eval("200²", "40000");
+	test_eval("13¹³ days", "302875106592253 days");
+}
